<?php

/*
Copyright (C) 2009-2013, Rémi Jean (zwiicms@outlook.com)
<http://zwiicms.com/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General License for more details.

You should have received a copy of the GNU General License
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

session_start();
define('VERSION','5.0.3');

class zwii
{
	var $settings_path,
		$pages_path,
		$system_path,
		$plugins_path,
		$templates_path,
		$langues_path,
		$settings,
		$url,
		$edit_mode,
		$system,
		$all,
		$plugins,
		$langues,
		$title,
		$error,
		$pages,
		$titles,
		$positions,
		$links,
		$head;

	/*
		Système
	*/

	function __construct()
	{
		$this->settings_path = 'zwii/data/settings.ini';
		$this->pages_path = 'zwii/data/pages/';
		$this->system_path = 'zwii/data/system.ini';
		$this->plugins_path = 'zwii/plugins/';
		$this->templates_path = 'zwii/templates/';
		$this->langues_path = 'zwii/langs/';
		$this->settings = parse_ini_file($this->settings_path);
		$this->url = !empty($_SERVER['QUERY_STRING']) ? $_SERVER['QUERY_STRING'] : '/page/' . $this->settings['home'];
		$this->url = explode('/', $this->url);
		if(empty($this->url[0]))
		{
			array_shift($this->url);
		}
		$this->session_edit();
		$this->edit_mode = (isset($_SESSION['EDIT_MODE'])) ? '?/edit/' : '?/page/';
		$this->system = parse_ini_file($this->system_path, true);
		$this->all = $this->system;
		$this->plugins = array();
		$this->langues[] = $this->langues_path . $this->settings['language'] . '.inc';
		$this->title = $this->t('Erreur 404');
		$this->head = array();
		$this->error = '<h2>' . $this->t('Erreur 404') . '</h2><p>' . $this->t('Page introuvable !') . '</p>';
		$this->import_plugins();
		$this->import_pages();
	}

	function builder()
	{
		$url = $this->url[0];
		if(array_key_exists($url, $this->all))
		{
			if(isset($this->all[$url]['public'])
			|| isset($_COOKIE['PASSWORD'])
			&& $_COOKIE['PASSWORD'] == $this->settings['password'])
			{
				if(array_key_exists($url, $this->system))
				{
					return $this->builder = $this->$url();
				}
				else
				{
					$plugin = new $url();
					$this->builder = $plugin->builder();
					return $this->title = $plugin->title;
				}
			}
			else
			{
				return $this->builder = $this->login();
			}
		}
		else
		{
			return $this->builder = $this->error;
		}
	}

	function template()
	{
		$this->settings_decode();
		if(is_file($path = $this->templates_path . $this->settings['template'] . '/index.html'))
		{
			require $path;
		}
		else
		{
			die($this->t('Template introuvable') . ' : ' . $path);
		}
	}

	function t($text)
	{
		$files = array();
		foreach($this->langues as $value)
		{
			if(is_file($value))
			{
				$tmp = file($value);
				$files = array_merge($files, $tmp);
			}
		}
		foreach($files as $key => $value)
		{
			$explode = explode(' = ', $value);
			$translate = trim($explode[1]);
			if($explode[0] == $text
			&& !empty($translate))
			{
				$text = $translate;
			}
		}
		return $text;
	}

	function save($array, $file, $array_key = false)
	{
		$rows = !empty($array_key) ? "\r\n[" . $array_key . "]" : false;
		foreach($array as $key => $value)
		{
			$rows .= "\r\n" . $key . ' = "' . $value . '"';
		}
		$rows = trim($rows);
		return file_put_contents($file, $rows);
	}

	function redirect($url, $pre = true)
	{
		$pre = !empty($pre) ? '?' : false;
		header('location:' . $pre . $url);
		exit;
	}

	function import_pages()
	{
		$handle = opendir($this->pages_path);
		while(false !== ($entry = readdir($handle)))
		{
			if(is_file($this->pages_path . $entry))
			{
				$id = basename($entry, '.ini');
				$content = parse_ini_file($this->pages_path . $entry);
				$this->pages[$id] = $content;
				$this->titles[$id] = $content['title'];
				$this->positions[$id] = $content['position'];
				$this->links[$content['link']] = $id;
			}
		}
		closedir($handle);
		asort($this->titles, SORT_STRING);
		asort($this->positions, SORT_NUMERIC);
	}

	function import_plugins()
	{
		$handle = opendir($this->plugins_path);
		while(false !== ($entry = readdir($handle)))
		{
			if(is_file($this->plugins_path . $entry . '/plugin.inc')
			&& is_file($this->plugins_path . $entry . '/plugin.ini'))
			{
				$vars = parse_ini_file($this->plugins_path . $entry . '/plugin.ini', true);
				$this->all = array_merge($this->all, $vars);
				$this->plugins = array_merge($this->plugins, $vars);
				$this->langues[] = $this->plugins_path . $entry . '/langs/' . $this->settings['language'] . '.inc';
				$this->head[] = array($this->plugins_path . $entry . '/extras/main.css', $this->plugins_path . $entry . '/extras/main.js');
			}
		}
		closedir($handle);
	}

	function meta($key)
	{
		if(array_key_exists($key, $this->settings))
		{
			if($this->url[0] == 'page'
			&& isset($this->url[1])
			&& !empty($this->pages[$this->url[1]]['meta_' . $key]))
			{
				return $this->pages[$this->url[1]]['meta_' . $key];
			}
			else
			{
				return ($key == 'title') ? $this->title . ' | ' . $this->settings['title'] : $this->settings[$key];
			}
		}
	}

	function css()
	{
		foreach($this->head as $key => $value)
		{
			@$css .= is_file($value[0]) ? '<link rel="stylesheet" href="' . $value[0] . '">' : false;
		}
		return @$css;
	}

	function scripts()
	{
		foreach($this->head as $key => $value)
		{
			@$scripts .= is_file($value[1]) ? '<script src="' . $value[1] . '"></script>' : false;
		}
		return @$scripts;
	}

	function menu()
	{
		foreach($this->positions as $key => $value)
		{
			if($this->pages[$key]['position'] > 0)
			{
				$current = ($this->url[0] == $key || isset($this->url[1]) && $this->url[1] == $key || !empty($this->links['?' . $_SERVER['QUERY_STRING']]) && $this->links['?' . $_SERVER['QUERY_STRING']] == $key) ? ' class="current"' : false;
				$blank = (!empty($this->pages[$key]['blank']) && $this->edit_mode !== '?/edit/') ? ' target="_blank"' : false;
				$link = (!empty($this->pages[$key]['link']) && $this->edit_mode !== '?/edit/') ? $this->pages[$key]['link'] : $this->edit_mode . $key;
				@$rows .= '<li><a href="' . $link . '"' . $current . $blank . '>' . $this->pages[$key]['title'] . "</a></li>";
			}
		}
		$rows = isset($rows) ? '<ul>' . $rows . '</ul>' : false;
		return $rows . @$hidden;
	}

	function panel()
	{
		if(isset($_COOKIE['PASSWORD'])
		&& $_COOKIE['PASSWORD'] == $this->settings['password'])
		{
			if(isset($_POST['list'])
			&& array_key_exists($_POST['list'], $this->pages))
			{
				return $this->redirect($this->edit_mode . $_POST['list'], false);
			}
			else
			{
				return '<div id="panel">'
					. '<ul>'
					. '<li>'
					. '<form name="form" method="post">'
					. '<select name="list" onchange="this.form.submit();">'
					. $this->pages_list_panel()
					. '</select>'
					. '</form>'
					. '</li>'
					. $this->shortcuts()
					. $this->phpversion()
					. '</ul>'
					. '</div>';
			}
		}
	}

	function popup()
	{
		if(isset($_SESSION['POPUP']))
		{
			$tmp = $_SESSION['POPUP'];
			unset($_SESSION['POPUP']);
			return '<div id="popup">' . $tmp . '</div>';
		}
	}

	function admin()
	{
		$panel = $this->panel();
		$spacing = !empty($panel) ? '<div id="spacing"></div>' : false;
		return $panel . $this->popup() . $spacing;
	}

	/*
		Plugins
	*/

	function login()
	{
		if(isset($_POST['submit']))
		{
			if(sha1($_POST['password']) == $this->settings['password'])
			{
				$time = empty($_POST['time']) ? 0 : time()+10*365*24*60*60;
				setcookie('PASSWORD', sha1($_POST['password']), $time);
				return $this->redirect($_SERVER['QUERY_STRING']);
			}
			else
			{
				$_SESSION['POPUP'] = $this->t('Mot de passe incorrect !');
				return $this->redirect($_SERVER['QUERY_STRING']);
			}
		}
		else
		{
			$this->title = $this->t('Connexion');
			return '<h2>' . $this->t('Connexion') . '</h2>'
				. '<form name="form" method="post">'
				. '<p>'
				. '<input type="password" name="password" class="little" placeholder="' . $this->t('Mot de passe') . '" required>'
				. '</p>'
				. '<p>'
				. '<input type="checkbox" id="time" name="time"><label for="time" class="checkbox"> ' . $this->t('Me connecter automatiquement lors de mes prochaines visites.') . '</label>'
				. '</p>'
				. '<p>'
				. '<input type="submit" name="submit" value="' . $this->t('Connexion') . '">'
				. '</p>'
				. '</form>';
		}
	}

	function logout()
	{
		if(isset($_COOKIE['PASSWORD']))
		{
			setcookie('PASSWORD');
			session_destroy();
		}
		header('location:./');
		exit;
	}

	function settings()
	{
		if(isset($_POST['submit']))
		{
			$this->save($this->new_settings(), $this->settings_path);
			$this->new_plugins_settings();
			return $this->redirect($_SERVER['QUERY_STRING']);
		}
		else
		{
			$this->title = $this->t('Paramètres');
			return '<h2>' . $this->t('Paramètres') . '</h2>'
				. '<h3>' . $this->t('Paramètres généraux') . '</h3>'
				. '<form name="form" method="post">'
				. '<p>'
				. '<label>' . $this->t('Titre du site') . '</label>'
				. '<input type="text" name="title" value="' . $this->settings['title'] . '">'
				. '<div class="tip">' . $this->t('Le titre du site englobe également la balise méta titre.') . '</div>'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Nouveau mot de passe') . '</label>'
				. '<input type="password" name="password" value="">'
				. '<div class="tip">' . $this->t('Laisser vide pour ne pas changer le mot de passe d\'administration.') . '</div>'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Page d\'accueil') . '</label>'
				. '<select name="home">'
				. $this->pages_list_settings()
				. '</select>'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Template par défaut') . '</label>'
				. '<select name="template">'
				. $this->templates_list($this->settings)
				. '</select>'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Langage du site') . '</label>'
				. '<select name="language">'
				. $this->languages_list()
				. '</select>'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Bas de page') . '</label>'
				. '<input type="text" name="footer" value="' . $this->settings['footer'] . '">'
				. '<div class="tip">' . $this->t('Texte en bas de page (merci de laisser une petite trace de Zwii).') . '</div>'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Balise méta description') . '</label>'
				. '<input type="text" name="description" value="' . $this->settings['description'] . '">'
				. '<div class="tip">' . $this->t('Description de 150 caractères maximum.') . '</div>'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Balise méta mots clés') . '</label>'
				. '<input type="text" name="keywords" value="' . $this->settings['keywords'] . '">'
				. '<div class="tip">' . $this->t('Mots clés séparés par des virgules.') . '</div>'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Version de Zwii') . '</label>'
				. '<input type="text" name="version" value="' . VERSION . '" readonly>'
				. '</p>'
				. '<h3>' . $this->t('Paramètres des plugins') . '</h3>'
				. $this->plugins_settings()
				. '<p>'
				. '<input type="submit" name="submit" value="' .  $this->t('Enregistrer') . '"> '
				. '</p>'
				. '</form>';
		}
	}

	function page()
	{
		if(@!$page = $this->pages[$this->url[1]])
		{
			return $this->error;
		}
		elseif(!empty($page['link']))
		{
			return $this->redirect($page['link'], false);
		}
		else
		{
			$this->title = $page['title'];
			$this->settings['template'] = (!empty($page['template']) && is_file($this->templates_path . $page['template'] . '/index.html')) ? $page['template'] : $this->settings['template'];
			$title = empty($page['hide']) ? '<h2>' . html_entity_decode($page['title'], ENT_COMPAT, 'UTF-8') . '</h2>' : false;
			return $title . html_entity_decode($page['content'], ENT_COMPAT, 'UTF-8');
		}
	}

	function add()
	{
		$new_page = array
		(
			'title' => $this->t('Nouvelle page'),
			'position' => 0,
			'hide' => '',
			'blank' => '',
			'link' => '',
			'template' => '',
			'meta_title' => '',
			'meta_description' => '',
			'meta_keywords' => '',
			'content' => '<p>' . $this->t('Contenu de la page.') . '</p>'
		);
		$_SESSION['POPUP'] = $this->t('Nouvelle page créée avec succès !');
		$name = $this->increment($this->clean($new_page['title']), '.ini', $this->pages_path);
		$this->save($new_page, $this->pages_path . $name . '.ini');
		return $this->redirect($this->edit_mode . $name, false);
	}

	function edit()
	{
		if(@!$page = $this->pages[$this->url[1]])
		{
			return $this->error;
		}
		elseif(isset($_POST['submit']))
		{
			if($_POST['title'] !== $page['title'])
			{
				$title = $this->clean($_POST['title']);
				$this->settings['home'] = ($page['title'] == $this->settings['home']) ? $title : $this->settings['home'];
				unlink($this->pages_path . $this->url[1] . '.ini');
				$name = $this->increment($title, '.ini', $this->pages_path);
			}
			else
			{
				$name = $this->url[1];
			}
			$this->save($this->new_content($name, $this->url[1]), $this->pages_path . $name . '.ini');
			return $this->redirect($this->edit_mode . $name, false);
		}
		else
		{
			$this->title = $this->t('Mode édition');
			$checked_hide = !empty($page['hide']) ? ' checked' : false;
			$checked_blank = !empty($page['blank']) ? ' checked' : false;
			return '<h2>' . $this->t('Mode édition') . '</h2>'
				. '<form name="form" method="post">'
				. '<p>'
				. '<label>' . $this->t('Titre de la page') . '</label>'
				. '<input type="text" name="title" value="' . $page['title'] . '">'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Position de la page') . '</label>'
				. '<input type="text" name="position" value="' . $page['position'] . '">'
				. '<div class="tip">' . $this->t('Saisir une valeur supérieure à 0 afin d\'afficher la page dans le menu.') . '</div>'
				. '</p>'
				. '<p>'
				. '<textarea id="content" name="content" class="wysiwyg">' . $page['content'] . '</textarea>'
				. '</p>'
				. '<div id="advanced_hide" class="hide">'
				. '<h3>' . $this->t('Paramètres avancés') . '</h3>'
				. '<p>'
				. '<input type="checkbox" id="hide" name="hide"' . $checked_hide . '><label for="hide" class="checkbox">' . $this->t('Cacher le titre de la page') . '</label>'
				. '</p>'
				. '<p>'
				. '<input type="checkbox" id="blank" name="blank"' . $checked_blank . '><label for="blank" class="checkbox">' . $this->t('Ouvrir dans un nouvel onglet') . '</label>'
				. '<div class="tip">' . $this->t('Ouvre la page dans un nouvel onglet (seulement en mode public).') . '</div>'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Lien de redirection') . '</label>'
				. '<input type="text" name="link" value="' . $page['link'] . '" placeholder="http://">'
				. '<div class="tip">' . $this->t('Redirection automatique de la page vers ce lien (seulement en mode public).') . '</div>'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Template de la page') . '</label>'
				. '<select name="template">'
				. $this->templates_list($page)
				. '</select>'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Balise méta titre') . '</label>'
				. '<input type="text" name="meta_title" value="' . $page['meta_title'] . '">'
				. '<div class="tip">' . $this->t('Remplace le contenu de la balise méta titre défini dans les paramètres.') . '</div>'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Balise méta description') . '</label>'
				. '<input type="text" name="meta_description" value="' . $page['meta_description'] . '">'
				. '<div class="tip">' . $this->t('Remplace le contenu de la balise méta description défini dans les paramètres.') . '</div>'
				. '</p>'
				. '<p>'
				. '<label>' . $this->t('Balise méta mots clés') . '</label>'
				. '<input type="text" name="meta_keywords" value="' . $page['meta_keywords'] . '">'
				. '<div class="tip">' . $this->t('Remplace le contenu de la balise méta mots clés défini dans les paramètres.') . '</div>'
				. '</p>'
				. '</div>'
				. '<p>'
				. '<input type="submit" name="submit" value="' . $this->t('Enregistrer') . '"> '
				. '<input type="button" value="' . $this->t('Paramètres avancés') . '" onClick="show_hide(\'advanced_hide\')">'
				. '</p>'
				. '</form>';
		}
	}

	function delete()
	{
		if(!isset($this->url[1])
		|| !array_key_exists($this->url[1], $this->pages))
		{
			return $this->error;
		}
		else
		{
			if($this->url[1] == $this->settings['home'])
			{
				$_SESSION['POPUP'] = $this->t('Impossible de supprimer la page d\'accueil !');
			}
			else
			{
				$_SESSION['POPUP'] = $this->t('Page supprimée avec succès !');
				unlink($this->pages_path . $this->url[1] . '.ini');
			}
			return $this->redirect($this->edit_mode . $this->settings['home'], false);
		}
	}

	function plugins()
	{
		$this->title = $this->t('Plugins');
		return '<h2>' . $this->t('Plugins') . '</h2>' . $this->plugins_list();
	}

	/*
		Fonctions
	*/

	function shortcuts()
	{
		foreach($this->system as $key => $value)
		{
			if(isset($value['shortcut']))
			{
				$confirm = (isset($value['confirm'])) ? ' onClick=\'return confirm("' . $value['confirm'] . '")\'' : false;
				if(is_numeric($value['shortcut']))
				{
					@$shortcuts .= '<li><a href="?/' . $key . '"' . $confirm . '>' . $this->t($value['name']) . '</a></li>';
				}
				else
				{
					$shortcut = explode('|', $value['shortcut']);
					foreach($shortcut as $sub_value)
					{
						if(!empty($this->links['?' . $_SERVER['QUERY_STRING']])
						&& $sub_value == 'page')
						{
							@$shortcuts .= '<li><a href="?/' . $key . '/' . $this->links['?' . $_SERVER['QUERY_STRING']] . '"' . $confirm . '>' . $this->t($value['name']) . '</a></li>';
						}
						elseif($sub_value == $this->url[0])
						{
							@$shortcuts .= '<li><a href="?/' . $key . '/' . $this->url[1] . '"' . $confirm . '>' . $this->t($value['name']) . '</a></li>';
						}
					}
				}
			}
		}
		return $shortcuts;
	}

	function phpversion()
	{
		if(phpversion() < 5.3)
		{
			return '<li id="phpversion">' . $this->t('PHP 5.3+ requis pour le bon fonctionnement de Zwii !') . '</li>';
		}
	}

	function pages_list_panel()
	{
		if(isset($this->url[1])
		&& ($this->url[0] == 'page'
		|| $this->url[0] == 'edit')
		&& array_key_exists($this->url[1], $this->pages)
		|| !empty($this->links['?' . $_SERVER['QUERY_STRING']]))
		{
			$options = '<option disabled>' . $this->t('Liste des pages') . '</option>';
			$disabled = true;
		}
		else
		{
			$options = '<option selected>' . $this->t('Liste des pages') . '</option>';
		}
		foreach($this->titles as $key => $value)
		{
			if(isset($this->url[1])
			&& $this->url[1] == $key
			&& isset($disabled)
			|| !empty($this->links['?' . $_SERVER['QUERY_STRING']])
			&& $key == $this->links['?' . $_SERVER['QUERY_STRING']])
			{
				$options .= '<option value="' . $key . '" selected>' . $this->pages[$key]['title'] . '</option>';
			}
			else
			{
				$options .= '<option value="' . $key . '">' . $this->pages[$key]['title'] . '</option>';
			}
		}
		return $options;
	}

	function pages_list_settings()
	{
		foreach($this->titles as $key => $value)
		{
			$selected = ($this->settings['home'] == $key) ? ' selected' : false;
			@$options .= '<option value="' . $key . '"' . $selected . '>' . $this->pages[$key]['title'] . '</option>';
		}
		return $options;
	}

	function templates_list($array)
	{
		$handle = opendir($this->templates_path);
		while(false !== ($entry = readdir($handle)))
		{
			if(is_file($this->templates_path . $entry . '/index.html'))
			{
				$selected = ($array['template'] == $entry) ? ' selected' : false;
				@$options .= '<option value="' . $entry . '"' . $selected . '>' . $entry . '</option>';
			}
		}
		closedir($handle);
		if($array !== $this->settings)
		{
			$selected = empty($selected) ? ' selected' : false;
			return '<option value=""' . $selected . '>' . $this->t('Template par défaut') . '</option>' . $options;
		}
		else
		{
			return $options;
		}
	}

	function languages_list()
	{
		$handle = opendir($this->langues_path);
		while(false !== ($entry = readdir($handle)))
		{
			if(is_file($this->langues_path . $entry))
			{
				$name = basename($entry, '.inc');
				$selected = ($this->settings['language'] == $name) ? ' selected' : false;
				@$options .= '<option value="' . $name . '"' . $selected . '>' . $name . '</option>';
			}
		}
		closedir($handle);
		return $options;
	}

	function new_settings()
	{
		$_SESSION['POPUP'] = $this->t('Paramètres enregistrés avec succès !');
		foreach($this->settings as $key => $value)
		{
			if(isset($_POST[$key]))
			{
				if($key == 'password')
				{
					if(empty($_POST[$key]))
					{
						$tmp = $this->settings[$key];
					}
					else
					{
						$tmp = sha1($_POST[$key]);
					}
				}
				else
				{
					$tmp = $this->replace($_POST[$key]);
				}
			}
			$this->settings[$key] = $tmp;
		}
		return $this->settings;
	}

	function new_plugins_settings()
	{
		foreach($this->plugins as $key => $value)
		{
			foreach($value as $sub_key => $sub_value)
			{
				if(isset($_POST[$key . $sub_key]))
				{
					$this->plugins[$key][$sub_key] = $this->replace($_POST[$key . $sub_key]);
				}
			}
			$this->save($this->plugins[$key], $this->plugins_path . $key . '/plugin.ini', $key);
		}
	}

	function plugins_settings()
	{
		foreach($this->plugins as $key => $value)
		{
			$title = '<h4>' . $this->t($value['name']) . '</h4>';
			foreach($value as $sub_key => $sub_value)
			{
				if(!in_array($sub_key, array('name', 'shortcut', 'public', 'confirm')))
				{
					$tip = ($this->t($sub_key . '_tip') !== $sub_key . '_tip') ? '<div class="tip">' . $this->t($sub_key . '_tip') .'</div>' : false;
					$blocks[$key][] = '<p>'
									. '<label>' . $this->t($sub_key) . '</label>'
									. '<input type="text" name="' . $key . $sub_key . '" value="' . $sub_value . '">'
									. $tip
									. '</p>';
				}
			}
			@$settings .= isset($blocks[$key]) ? $title . implode($blocks[$key]) : false;
		}
		return isset($settings) ? $settings : '<p>' . $this->t('Aucun plugin.') . '</p>';
	}

	function replace($str)
	{
		$str = stripslashes($str);
		return str_replace('"', '&quot;', $str);
	}

	function clean($str)
	{
		$str = strtolower($str);
		$search = explode(',', 'á,à,â,ä,ã,å,ç,é,è,ê,ë,í,ì,î,ï,ñ,ó,ò,ô,ö,õ,ú,ù,û,ü,ý,ÿ, ');
		$replace = explode(',', 'a,a,a,a,a,a,c,e,e,e,e,i,i,i,i,n,o,o,o,o,o,u,u,u,u,y,y,-');
		$str = str_replace($search, $replace, $str);
		$str = preg_replace('#[^a-z0-9-]#', '', $str);
		return $str;
	}

	function increment($str, $extension = false, $path = false)
	{
		$i = 2;
		$new_str = $str;
		while(false !== file_exists($path . $new_str . $extension))
		{
			$new_str = $str . '-' . $i;
			$i++;
		}
		return $new_str;
	}

	function new_content($new, $old)
	{
		foreach($this->pages[$old] as $key => $value)
		{
			if($key == 'position')
			{
				$tmp = is_numeric($_POST[$key]) ? $_POST[$key] : 0;
			}
			elseif($key == 'link')
			{
				if(!empty($_POST[$key])
				&& array_key_exists($_POST[$key], $this->links)
				&& $_POST[$key] !== $value)
				{
					$_SESSION['POPUP'] = $this->t('Page enregistrée avec succès, sauf le lien de redirection car il est déjà utilisé dans une autre page !');
				}
				else
				{
					$tmp = $this->replace($_POST[$key]);
					$_SESSION['POPUP'] = $this->t('Page enregistrée avec succès !');
				}
			}
			else
			{
				$tmp = $this->replace(@$_POST[$key]);
			}
			$this->pages[$new][$key] = $tmp;
		}
		return $this->pages[$new];
	}

	function session_edit()
	{
		switch($this->url[0])
		{
			case 'edit' :
				if(!isset($_SESSION['EDIT_MODE'])
				&& isset($_COOKIE['PASSWORD'])
				&& $_COOKIE['PASSWORD'] == $this->settings['password'])
				{
					$_SESSION['EDIT_MODE'] = true;
				}
				break;
			case 'page' :
				if(isset($_SESSION['EDIT_MODE']))
				{
					unset($_SESSION['EDIT_MODE']);
				}
				break;
		}
	}

	function plugins_list()
	{
		foreach($this->plugins as $key => $value)
		{
			@$rows .= '<tr>'
					. '<td><a href="?/' . $key . '">' . $this->t($this->plugins[$key]['name']) . '</a></td>'
					. '</tr>';
		}
		$rows = !empty($rows) ? $rows : '<tr><td colspan="3">' . $this->t('Aucun plugin.') . '</td></tr>';
		return '<table>'
			. '<tr><th>' . $this->t('Liste des plugins') . '</th></tr>'
			. $rows
			. '</table>';
	}

	function link()
	{
		if(($this->url[0] == 'page'
		|| $this->url[0] == 'edit')
		&& !empty($this->url[1]))
		{
			$link = 'edit/' . $this->url[1];
		}
		else
		{
			$link = 'settings';
		}
		return '<a href="?/' . $link . '">' . $this->t('Administration') . '</a>';
	}

	function settings_decode()
	{
		foreach($this->settings as $key => $value)
		{
			$this->settings[$key] = html_entity_decode($value, ENT_COMPAT, 'UTF-8');
		}
		return $this->settings;
	}
}

?>